package org.acme.security.keycloak.authorization;

import io.quarkus.test.junit.QuarkusIntegrationTest;

/**
 * @author <a href="mailto:psilva@redhat.com">Pedro Igor</a>
 */
@QuarkusIntegrationTest
public class NativePolicyEnforcerIT extends PolicyEnforcerTest {
}
